ARBItemSpecialDataOption class
Special data option For plural it can be {zero:"zero messages"},{other:"count of messages"}
Constructors
- ARBItemSpecialDataOption(String key, String text)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → ARBAttributeKey
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → ARBAttributeKey
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → ARBAttributeKey -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited