TranslationOptions class

Specifies how specific ARB items should be processed by translator

Constructors

TranslationOptions({bool translateEqualToSource = false, bool overrideExistEntries = false, List<ARBItemKey>? keys, List<ARBItemKey>? ignoreKeys})
const
TranslationOptions.createDefault()
Shortcut
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreKeys → List<ARBItemKey>?
final
keys → List<ARBItemKey>?
final
overrideExistEntries → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translateEqualToSource → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withFlags({bool? translateEqual, bool? overrideExist}) → TranslationOptions
Overrides default flags
withIgnoreKeys(List<ARBItemKey> ignoreKeyList) → TranslationOptions
Overrides default ignore key list
withKeys(List<ARBItemKey> keyList) → TranslationOptions
Overrides default key list

Operators

operator ==(Object other) → bool
The equality operator.
inherited