ARBParser class

Reads ARB file and generates ARBContent based on it's content

Constructors

ARBParser({required Logger logger})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String path) → ARBContent
path - absolute path to the .arb file
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited